@@ -34,8 +34,8 @@ setConstructorS3("AromaTabularBinaryFile", function(...) {
   );
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  pathname <- getPathname(this)
+  setAttributesByTags(this)
 
   this;
 })
