@@ -5,8 +5,7 @@ setConstructorS3("AromaUnitChromosomeTabularBinaryFile", function(...) {
   );
 
   # Parse attributes (all subclasses must call this in the constructor).
-  if (!is.null(this$.pathname))
-    setAttributesByTags(this);
+  setAttributesByTags(this)
 
   this;
 }, abstract=TRUE)
@@ -51,7 +50,7 @@ setMethodS3("getChromosomes", "AromaUnitChromosomeTabularBinaryFile", function(t
     chromosomes <- sort(chromosomes);
     this$.chromosomes <- chromosomes;
   }
-  
+
   chromosomes;
 })
 
@@ -97,7 +96,7 @@ setMethodS3("getUnitsOnChromosomes", "AromaUnitChromosomeTabularBinaryFile", fun
   cc <- indexOfColumn(this, "chromosome");
   data <- this[,cc,drop=TRUE];
 
-  # Update known chromosomes, if not already done.  
+  # Update known chromosomes, if not already done.
   allChromosomes <- getChromosomes(this, .chromosomes=data);
 
   res <- vector("list", length(chromosomes));
@@ -129,7 +128,7 @@ setMethodS3("getUnitsOnChromosome", "AromaUnitChromosomeTabularBinaryFile", func
   # Argument 'chromosome':
   chromosome <- Arguments$getIndex(chromosome);
 
-  units <- getUnitsOnChromosomes(this, chromosomes=chromosome, 
+  units <- getUnitsOnChromosomes(this, chromosomes=chromosome,
                                  unlist=TRUE, useNames=FALSE);
   units;
 }, protected=TRUE)
@@ -170,9 +169,9 @@ setMethodS3("allocate", "AromaUnitChromosomeTabularBinaryFile", function(static,
   footer <- c(
     list(
       createdOn=format(Sys.time(), "%Y%m%d %H:%M:%S", usetz=TRUE),
-      platform=platform, 
+      platform=platform,
       chipType=chipType
-    ), 
+    ),
     footer
   );
 
@@ -190,7 +189,7 @@ setMethodS3("allocate", "AromaUnitChromosomeTabularBinaryFile", function(static,
 #   to also support alias argument 'units', we now do 'rows=units' and
 #   'units=NULL'.
 # 2012-10-31
-# o Added argument 'units' to readDataFrame() for 
+# o Added argument 'units' to readDataFrame() for
 #   AromaUnitChromosomeTabularBinaryFile.
 # 2011-03-03
 # o ROBUSTNESS: Added a return contract/sanity check asserting that
