@@ -3,15 +3,15 @@ setConstructorS3("CbsSegmentationDataSet", function(...) {
 })
 
 setMethodS3("byPath", "CbsSegmentationDataSet", function(static, ..., pattern=",chr[0-9]+,.*[.]xdr$") {
-  byPath.GenericDataFileSet(static, ..., pattern=pattern);
-}, static=TRUE)
+  NextMethod("byPath", pattern=pattern);
+}, static=TRUE, protected=TRUE)
 
 
 setMethodS3("byName", "CbsSegmentationDataSet", function(static, ..., chipType, paths="cbsData/") {
   # Argument 'chipType':
   chipType <- Arguments$getCharacter(chipType);
 
-  byName.GenericDataFileSet(static, ..., subdirs=chipType, paths=paths);
+  NextMethod("byName", subdirs=chipType, paths=paths);
 }, static=TRUE)
 
 
