@@ -6,17 +6,17 @@
 # \description{
 #  @classhierarchy
 #
-#  This class represents the Haar wavelet-based segmentation (HaarSeg) 
-#  model [1]. 
+#  This class represents the Haar wavelet-based segmentation (HaarSeg)
+#  model [1].
 # }
-# 
+#
 # @synopsis
 #
 # \arguments{
 #   \item{cesTuple}{A @see "CopyNumberDataSetTuple".}
-#   \item{breaksFdrQ}{Default tuning parameters specific to the HaarSeg 
+#   \item{breaksFdrQ}{Default tuning parameters specific to the HaarSeg
 #         algorithm.}
-#   \item{...}{Arguments passed to the constructor of 
+#   \item{...}{Arguments passed to the constructor of
 #              @see "CopyNumberSegmentationModel".}
 # }
 #
@@ -25,7 +25,7 @@
 # }
 #
 # @author
-# 
+#
 # \seealso{
 #  @see "CopyNumberSegmentationModel".
 # }
@@ -34,13 +34,14 @@
 #   [1] Ben-Yaacov E. and Eldar YC. \emph{A fast and flexible method for the segmentation of aCGH data}, Bioinformatics, 2008.
 #   \url{http://www.ee.technion.ac.il/Sites/People/YoninaEldar/Info/software/HaarSeg.htm}
 # }
-#*/########################################################################### 
+#*/###########################################################################
 setConstructorS3("HaarSegModel", function(cesTuple=NULL, ..., breaksFdrQ=0.0001) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Load required packages
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   if (!is.null(cesTuple)) {
-    require("HaarSeg") || throw("Package not loaded: HaarSeg");
+    # Early error, iff package is not installed
+    requireNamespace("HaarSeg") || throw("Package not loaded: HaarSeg");
   }
 
   # Argument 'breaksFdrQ':
@@ -67,7 +68,7 @@ setMethodS3("getFitFunction", "HaarSegModel", function(this, ...) {
 # 2009-05-16
 # o Added getFitFunction().  Removed fitOne().
 # 2008-05-14
-# o Moved drawCnRegions(), extractCopyNumberRegions() and 
+# o Moved drawCnRegions(), extractCopyNumberRegions() and
 #   extractRawCopyNumbers() for HaarSeg to aroma.core v1.0.6 (will
 #   eventually end up in aroma.cn).
 # 2008-01-26
@@ -78,4 +79,4 @@ setMethodS3("getFitFunction", "HaarSegModel", function(this, ...) {
 # o Now using the HaarSeg package (put together by HB).
 # 2008-12-16
 # o Created.
-############################################################################## 
+##############################################################################
